@@ -16,7 +16,8 @@ SearchOptionsData::SearchOptionsData()
       searchPath(QDir::homePath()),
       includeHidden(false),
       maxResults(-1),
-      resultFoundEnabled(false)
+      resultFoundEnabled(false),
+      detailedResultsEnabled(false)
 {
 }
 
@@ -140,6 +141,16 @@ bool SearchOptions::resultFoundEnabled() const
     return d->resultFoundEnabled;
 }
 
+void SearchOptions::setDetailedResultsEnabled(bool enable)
+{
+    d->detailedResultsEnabled = enable;
+}
+
+bool SearchOptions::detailedResultsEnabled() const
+{
+    return d->detailedResultsEnabled;
+}
+
 void SearchOptions::setSyncSearchTimeout(int seconds)
 {
     d->syncSearchTimeoutSecs = seconds;
@@ -150,4 +161,20 @@ int SearchOptions::syncSearchTimeout() const
     return d->syncSearchTimeoutSecs;
 }
 
+void SearchOptions::setBatchTime(int milliseconds)
+{
+    // 限制批处理时间范围在 50ms 到 5000ms 之间
+    if (milliseconds < 50) {
+        milliseconds = 50;
+    } else if (milliseconds > 5000) {
+        milliseconds = 5000;
+    }
+    d->batchTimeMs = milliseconds;
+}
+
+int SearchOptions::batchTime() const
+{
+    return d->batchTimeMs;
+}
+
 DFM_SEARCH_END_NS
